@@ -30,6 +30,6 @@ test_that("Example works", {
 })
 
 test_that("We can print a post result", {
-    expect_output(ret,
+    expect_output(print(ret),
      "\\(QueryKey = \\d+, WebEnv = [A-Z0-9_]+\\.\\.\\.\\)") 
 })
